@@ -4,11 +4,12 @@ from webspace.cms.amp.mixins import AmpMixin
 from webspace.cms.bakery.abstract import WagtailPageBakeryModel
 from webspace.cms import constants
 from webspace.loader import get_model
+from webspace.cms.forms.abstract import FormMixin
 
 GenericPage = get_model('cms', 'GenericPage')
 
 
-class AContentPage(AmpMixin, WagtailPageBakeryModel, GenericPage):
+class AContentPage(AmpMixin, FormMixin, WagtailPageBakeryModel, GenericPage):
     template = '%s/content_page.html' % constants.PAGES_TEMPLATES_PATH
 
     promote_panels = GenericPage.promote_panels + [
